==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/event/RequestEvent.h <==
// public class gnu.java.net.protocol.http.event.RequestEvent

// class file dependencies
// @dep_class 6cf04f6c46d97006 gnu_java_net_protocol_http_event_RequestEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_gnu_java_net_protocol_http_event_RequestEvent_H_
#define _JC_gnu_java_net_protocol_http_event_RequestEvent_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Request$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs	_jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs	_jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$refs	_jc_gnu_java_net_protocol_http_event_RequestEvent$refs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs	_jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object	_jc_gnu_java_net_protocol_http_event_RequestEvent$object;

typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct	_jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods	_jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtable	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtype	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct {
	jint	REQUEST__5fCREATED;
	jint	REQUEST__5fSENDING;
	jint	REQUEST__5fSENT;
};
extern _jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct _jc_gnu_java_net_protocol_http_event_RequestEvent$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_event_RequestEvent$method$_init$8bef45032d797d20(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_gnu_java_net_protocol_http_Request$object *);

// Virtual methods
extern struct _jc_gnu_java_net_protocol_http_Request$object *_jc_gnu_java_net_protocol_http_event_RequestEvent$method$getRequest$2acd4818cfbd9509(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *);
extern jint _jc_gnu_java_net_protocol_http_event_RequestEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_event_RequestEvent$method_info$getRequest$2acd4818cfbd9509;
extern _jc_method _jc_gnu_java_net_protocol_http_event_RequestEvent$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods {
	struct _jc_gnu_java_net_protocol_http_Request$object	*(*getRequest$2acd4818cfbd9509)(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *);
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods	gnu_java_net_protocol_http_event_RequestEvent;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs {
	struct _jc_gnu_java_net_protocol_http_Request$object	*request;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$refs {
    _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs	gnu_java_net_protocol_http_event_RequestEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs	gnu_java_net_protocol_http_event_RequestEvent;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object {
	_jc_gnu_java_net_protocol_http_event_RequestEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_event_RequestEvent$vtype _jc_gnu_java_net_protocol_http_event_RequestEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_event_RequestEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_event_RequestEvent$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_event_RequestEvent_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/event/RequestEvent.h <==
// public class gnu.java.net.protocol.http.event.RequestEvent

// class file dependencies
// @dep_class 6cf04f6c46d97006 gnu_java_net_protocol_http_event_RequestEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_gnu_java_net_protocol_http_event_RequestEvent_H_
#define _JC_gnu_java_net_protocol_http_event_RequestEvent_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Request$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs	_jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs	_jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$refs	_jc_gnu_java_net_protocol_http_event_RequestEvent$refs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs	_jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object	_jc_gnu_java_net_protocol_http_event_RequestEvent$object;

typedef struct _jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct	_jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods	_jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtable	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtype	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct {
	jint	REQUEST__5fCREATED;
	jint	REQUEST__5fSENDING;
	jint	REQUEST__5fSENT;
};
extern _jc_gnu_java_net_protocol_http_event_RequestEvent$fields_struct _jc_gnu_java_net_protocol_http_event_RequestEvent$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_event_RequestEvent$method$_init$8bef45032d797d20(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_gnu_java_net_protocol_http_Request$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_net_protocol_http_Request$object *_jc_gnu_java_net_protocol_http_event_RequestEvent$method$getRequest$2acd4818cfbd9509(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_event_RequestEvent$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_event_RequestEvent$method_info$getRequest$2acd4818cfbd9509;
extern _jc_method _jc_gnu_java_net_protocol_http_event_RequestEvent$method_info$getType$74c20eac6b18d047;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods {
	struct _jc_gnu_java_net_protocol_http_Request$object	*(*getRequest$2acd4818cfbd9509)(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *) _JC_JCNI_ATTR;
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$vmethods	gnu_java_net_protocol_http_event_RequestEvent;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs {
	struct _jc_gnu_java_net_protocol_http_Request$object	*request;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$refs {
    _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_refs	gnu_java_net_protocol_http_event_RequestEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_gnu_java_net_protocol_http_event_RequestEvent$sub_nonrefs	gnu_java_net_protocol_http_event_RequestEvent;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_event_RequestEvent$object {
	_jc_gnu_java_net_protocol_http_event_RequestEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_event_RequestEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_event_RequestEvent$vtype _jc_gnu_java_net_protocol_http_event_RequestEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_event_RequestEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_event_RequestEvent$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_event_RequestEvent_H_ */
